@@ -25,10 +25,6 @@ from multiprocessing import Queue
 from time import sleep
 
 
-class KBInterrupt(Exception):
-    pass
-
-
 class Process(Proc):
     _do_run: bool = False
 
@@ -44,7 +40,7 @@ class Process(Proc):
         pass
 
     def work(self):
-        raise Exception("This method should be overridden.")
+        raise Exception("Overwrite me")
 
     def run(self) -> None:
         self.on_start()
@@ -55,11 +51,11 @@ class Process(Proc):
     def stop(self):
         self._do_run = False
 
-    @staticmethod
-    def sleep(n: float):
+    def sleep(self, n: float):
         try:
             sleep(n)
         except KeyboardInterrupt:
+            self.stop()
             pass
 
     def is_running(self):
